@@ -112,6 +112,8 @@ static const GstVideoFormatMap gst_vaapi_video_default_formats[] = {
 
   DEF_YUV (VA_BYTE_ORDER_NOT_CARE, Y210, Y210, ('Y', '2', '1', '0'), 32, 422_10BPP),
   DEF_YUV (VA_BYTE_ORDER_NOT_CARE, Y410, Y410, ('Y', '4', '1', '0'), 32, 444_10BPP),
+  DEF_YUV (VA_BYTE_ORDER_NOT_CARE, Y212_LE, Y212, ('Y', '2', '1', '2'), 32, 422_12BPP),
+  DEF_YUV (VA_BYTE_ORDER_NOT_CARE, Y412_LE, Y412, ('Y', '4', '1', '2'), 32, 444_12BPP),
 
   /* RGB formats */
   DEF_RGB (VA_LSB_FIRST, ARGB, BGRA8888, ('A', 'R', 'G', 'B'), 32, 32, 0x0000ff00,
@@ -466,6 +468,10 @@ gst_vaapi_video_format_from_chroma (guint chroma_type)
       return GST_VIDEO_FORMAT_Y210;
     case GST_VAAPI_CHROMA_TYPE_YUV444_10BPP:
       return GST_VIDEO_FORMAT_Y410;
+    case GST_VAAPI_CHROMA_TYPE_YUV444_12BPP:
+      return GST_VIDEO_FORMAT_Y412_LE;
+    case GST_VAAPI_CHROMA_TYPE_YUV422_12BPP:
+      return GST_VIDEO_FORMAT_Y212_LE;
     default:
       return GST_VIDEO_FORMAT_UNKNOWN;
   }
